# mt-ban-ascii.pl
# - Deny or moderate ASCII or Latin-1 comment using MT3 CommentFilter API
#
# It requires Perl 5.8 or over.
#
# Author:  Tatsuhiko Miyagawa <miyagawa at bulknews.net>
# License: same as Perl
#
# Ported to MT 4.x CommentThrottleFilter by Yujiro ARAKI.
# asciiCommentfilter.pl
# 2008.11.10 0.01

package MT::Plugin::asciiCommentfilter;

use strict;
use warnings;

use base qw( MT::Plugin );

our $VERSION = '0.01';

my $plugin = __PACKAGE__->new ({
    id => 'ASCII Comment Filter Plugin',
    name => 'ASCII Comment Filter Plugin',
    description => '<MT_TRANS phrase="Filter only ascii comment.">',
#    doc_link => 'http://www.koikikukan.com/archives/2008/11/10-005555.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    version => $VERSION,
    l10n_class => 'asciiCommentfilter::L10N',
    blog_config_template => 'config.tmpl',
    settings => new MT::PluginSettings ([
        ['asciiCommentfilter', { Default => 1, Scope => 'blog' }],
        ['asciiCommentfilterLog', { Default => '', Scope => 'blog' }],
    ]),
});
MT->add_plugin($plugin);

sub instance { $plugin; }

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
             'CommentThrottleFilter' => \&ascii_comment_filter,
        },
   });
}

use asciiCommentfilter::Util qw( is_filter is_log log );
sub ascii_comment_filter {
    my($cb, $app, $entry) = @_;
    my $id = $app->blog->id if $app->blog;
    return 1 if !is_filter($id);

    my $q = $app->param;
    eval { require Encode; };
    if ($@) {
        $app->log("Please use perl 5.8 for this plugin.");
        return 1;
    }
    my $text = Encode::decode(MT::ConfigMgr->instance->PublishCharset, $q->param('text') || '');
    if ($text =~ /^[\x00-\xff]+$/) {
        log($app, $q, 'Filter ascii comment.') if is_log($id);
        return 0;
    }
    return 1;
}

1;
